scoretools.set_measure_denominator_and_adjust_numerator
=======================================================

.. autofunction:: abjad.tools.scoretools.set_measure_denominator_and_adjust_numerator.set_measure_denominator_and_adjust_numerator
